@@ -5,10 +5,10 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.13_02';
+our $VERSION = '0.13_03';
 $VERSION =~ tr/_//d;
 
-use Carp qw(verbose); # makes carp() cluck and croak() confess
+use Carp qw(verbose);    # makes carp() cluck and croak() confess
 
 sub _warn {
   if ($_[-1] =~ /\n$/s) {
@@ -33,7 +33,8 @@ my %OLD_SIG;
 
 BEGIN {
   @OLD_SIG{qw(__DIE__ __WARN__)} = @SIG{qw(__DIE__ __WARN__)};
-  $SIG{__DIE__} = \&_die;
+
+  $SIG{__DIE__}  = \&_die;
   $SIG{__WARN__} = \&_warn;
 }
 
@@ -42,7 +43,6 @@ END {
 }
 
 1;
-__END__
 
 =encoding utf8
 
@@ -54,8 +54,7 @@ Carp::Always - Warns and dies noisily with stack backtraces
 
   use Carp::Always;
 
-makes every C<warn()> and C<die()> complains loudly in the calling package 
-and elsewhere. More often used on the command line:
+Often used on the command line:
 
   perl -MCarp::Always script.pl
 
@@ -81,15 +80,14 @@ looks:
           main::f('undef') called at -e line 2
           main::g() called at -e line 2
 
-In the implementation, the C<Carp> module does
+In the implementation, the L<Carp> module does
 the heavy work, through C<longmess()>. The
 actual implementation sets the signal hooks
 C<$SIG{__WARN__}> and C<$SIG{__DIE__}> to
 emit the stack backtraces.
 
-Oh, by the way, C<carp> and C<croak> when requiring/using
-the C<Carp> module are also made verbose, behaving
-like C<cluck> and C<confess>, respectively.
+Also, all uses of C<carp> and C<croak> are made verbose,
+behaving like C<cluck> and C<confess>.
 
 =head2 EXPORT
 
@@ -102,15 +100,12 @@ of L<Acme::JavaTrace> by Sébastien Aperghis-Tramoni.
 Sébastien also has a newer module called
 L<Devel::SimpleTrace> with the same code and fewer flame
 comments on docs. The pruning of the uselessly long
-docs of this module were prodded by Michael Schwern.
+docs of this module was prodded by Michael Schwern.
 
 Schwern and others told me "the module name stinked" -
 it was called C<Carp::Indeed>. After thinking long
-and not getting nowhere, I went with nuffin's suggestion
+and getting nowhere, I went with nuffin's suggestion
 and now it is called C<Carp::Always>. 
-C<Carp::Indeed> which is now deprecate
-lives in its own distribution (which won't go anywhere
-but will stay there as a redirection to this module).
 
 =head1 SEE ALSO
 
@@ -141,9 +136,9 @@ Test scripts are good. I should write more of these.
 =back
 
 Please report bugs via GitHub
-https://github.com/aferreira/cpan-Carp-Always/issues
+L<https://github.com/aferreira/cpan-Carp-Always/issues>
 
-Backlog in CPAN RT: https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Always
+Backlog in CPAN RT: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Always>
 
 =head1 AUTHOR
 
